using System;
using System.Diagnostics;
using System.Windows.Media;
using Styx.Common;

namespace NuokRealmHop
{
    public class PerformanceLogger : IDisposable
    {
        private readonly string _blockName;
        private readonly bool _isEnabled;
        private readonly Stopwatch _stopwatch;
        private bool _isDisposed;

        public PerformanceLogger(bool isEnabled, string blockName)
        {
            _isEnabled = isEnabled;
            _blockName = blockName;
            if (!_isEnabled) return;
            _stopwatch = new Stopwatch();
            _stopwatch.Start();
        }

        #region IDisposable Members

        public void Dispose()
        {
            if (_isDisposed) return;
            _isDisposed = true;
            if (_isEnabled)
            {
                _stopwatch.Stop();
                Log("Execution of the block {0} took {1}ms.", _blockName,
                    _stopwatch.ElapsedMilliseconds);
            }
            GC.SuppressFinalize(this);
        }

        #endregion

        private static void Log(string format, params object[] args)
        {
            Logging.WriteDiagnostic(Colors.Red, "NuokRealmHop: " + format, args);
        }

        ~PerformanceLogger()
        {
            Dispose();
        }
    }
}