﻿using System.ComponentModel;
using System.IO;
using Styx;
using Styx.Common;
using Styx.Helpers;

namespace NuokRealmHop
{
    internal class NSettings : Settings
    {
        private static NSettings _instance;

        public NSettings()
            : base(Path.Combine(CharacterSettingsPath, "NSettings.xml"))
        {
        }

        public static string CharacterSettingsPath
        {
            get
            {
                var settingsDirectory = Path.Combine(Utilities.AssemblyDirectory, "Settings");
                return Path.Combine(Path.Combine(settingsDirectory, "NSettings", StyxWoW.Me.RealmName),
                    StyxWoW.Me.Name);
            }
        }

        public static NSettings Instance => _instance ?? (_instance = new NSettings());

        #region Search Categories
        [Setting]
        [Category("Search Categories")]
        [DisplayName("Questing")]
        [Styx.Helpers.DefaultValue(false)]
        public bool Questing { get; set; }

        [Setting]
        [Category("Search Categories")]
        [DisplayName("Dungeons")]
        [Styx.Helpers.DefaultValue(false)]
        public bool Dungeons { get; set; }

        [Setting]
        [Category("Search Categories")]
        [DisplayName("Raids")]
        [Styx.Helpers.DefaultValue(false)]
        public bool Raids { get; set; }

        [Setting]
        [Category("Search Categories")]
        [DisplayName("Arenas")]
        [Styx.Helpers.DefaultValue(false)]
        public bool Arenas { get; set; }

        [Setting]
        [Category("Search Categories")]
        [DisplayName("Scenarios")]
        [Styx.Helpers.DefaultValue(false)]
        public bool Scenarios { get; set; }

        [Setting]
        [Category("Search Categories")]
        [DisplayName("Custom")]
        [Styx.Helpers.DefaultValue(true)]
        public bool Custom { get; set; }

        [Setting]
        [Category("Search Categories")]
        [DisplayName("Skirmishes")]
        [Styx.Helpers.DefaultValue(false)]
        public bool Skirmishes { get; set; }

        [Setting]
        [Category("Search Categories")]
        [DisplayName("Battlegrounds")]
        [Styx.Helpers.DefaultValue(false)]
        public bool Battlegrounds { get; set; }

        [Setting]
        [Category("Search Categories")]
        [DisplayName("Rated Battlegrounds")]
        [Styx.Helpers.DefaultValue(false)]
        public bool Ratedbgs { get; set; }

        [Setting]
        [Category("Search Categories")]
        [DisplayName("Ashran")]
        [Styx.Helpers.DefaultValue(false)]
        public bool Ashran { get; set; }

        #endregion

        #region Filters
        [Setting]
        [Category("Filters")]
        [DisplayName("Auto Invite Only")]
        [Styx.Helpers.DefaultValue(true)]
        public bool AutoInvite { get; set; }

        [Setting]
        [Category("Filters")]
        [DisplayName("Max Party Size")]
        [Styx.Helpers.DefaultValue(5)]
        [Limit(1, 40)]
        public int MaxPartySize { get; set; }

#endregion

        [Setting]
        [Category("Options")]
        [DisplayName("Auto Leave After X Minuets")]
        [Limit(0, 30)]
        [Styx.Helpers.DefaultValue(0)]
        public int LeaveAfterMin { get; set; }

        [Setting]
        [Category("Options")]
        [DisplayName("Auto Leave After X Minuets")]
        [Limit(0, 60)]
        [Styx.Helpers.DefaultValue(0)]
        public int LeaveAfterSeconds { get; set; }

        [Setting]
        [Category("Options")]
        [DisplayName("Realm Blacklist Timer")]
        [Description("Sets the minimum minutes before considering jumping back to a realm")]
        [Limit(0, 30)]
        [Styx.Helpers.DefaultValue(5)]
        public int RealmBlacklist { get; set; }

        [Setting]
        [Category("Options")]
        [DisplayName("Delay Pulse")]
        [Description("Delays the pulse to increase wow performance but slow down this plugin")]
        [Limit(0, 100)]
        [Styx.Helpers.DefaultValue(30)]
        public int DelayPulse { get; set; }

        [Setting]
        [Category("Options")]
        [DisplayName("Leave if your group leader")]
        [Styx.Helpers.DefaultValue(false)]
        public bool LeaderLeaver { get; set; }

        [Setting]
        [Category("Options")]
        [DisplayName("Category Search Delay (Seconds)")]
        [Description("Sets the minimim time in seconds for when a category can be searched.")]
        [Limit(0, 100)]
        [Styx.Helpers.DefaultValue(40)]
        public int CatSearchDelay { get; set; }

        [Setting]
        [Category("Debug")]
        [DisplayName("Debug Performance")]
        [Description("Enables Diagnostic Logging of Calls")]
        [Styx.Helpers.DefaultValue(false)]
        public bool DebugPerformace { get; set; }

        [Setting]
        [Category("Debug")]
        [DisplayName("Detailed Debug")]
        [Description("Enables more detailed debugging")]
        [Styx.Helpers.DefaultValue(true)]
        public bool DebugDetailed { get; set; }
    }
}